
#include <chronoptics/tof.h>

#include <mex.hpp>
#include <mexAdapter.hpp>
#include <unordered_map>
#include "handle_data.hpp"

using namespace matlab;

class MexFunction : public mex::Function {
  std::shared_ptr<engine::MATLABEngine> engine_ = getEngine();
  data::ArrayFactory factory_;

  void error_(const std::string &msg) {
    engine_->feval(u"error", 0, std::vector<data::Array>({factory_.createScalar(msg)}));
  }

  bool check_error_(tof_error_t error) {
    if (!error) return false;

    std::string message(tof_error_message(error));
    tof_error_delete(error);
    error_(message);

    return true;
  }

 public: 

  void operator()(mex::ArgumentList outputs, mex::ArgumentList inputs) {
    if (inputs.size() < 1 || inputs[0].getType() != data::ArrayType::CHAR) {
      error_("First argument should be function name");
    }

    data::CharArray char_array = inputs[0];
    auto function_name = char_array.toAscii();

    auto it = function_map_.find(function_name);
    if (it != function_map_.end()) {
      (*this.*it->second)(outputs, inputs);
    } else {
      error_("Function name not recognized");
    }
  }

 private:

  using FunctionPointer = void (MexFunction::*)(mex::ArgumentList, mex::ArgumentList);
  std::unordered_map<std::string, FunctionPointer> function_map_{
    {"tof_stream_delete", &MexFunction::tofStreamDelete},
    {"tof_stream_frame_type", &MexFunction::tofStreamFrameType},
    {"tof_stream_frame_id", &MexFunction::tofStreamFrameId},
    {"tof_stream_modulation_frequency", &MexFunction::tofStreamModulationFrequency},
    {"tof_stream_integration_time", &MexFunction::tofStreamIntegrationTime},
    {"tof_stream_process", &MexFunction::tofStreamProcess},
    {"tof_frame_type_to_string", &MexFunction::tofFrameTypeToString},
    {"tof_data_delete", &MexFunction::tofDataDelete},
    {"tof_data_data", &MexFunction::tofDataData},
    {"tof_data_size", &MexFunction::tofDataSize},
    {"tof_data_get_user_data", &MexFunction::tofDataGetUserData},
    {"tof_data_set_user_data", &MexFunction::tofDataSetUserData},
    {"tof_data_mat_type", &MexFunction::tofDataMatType},
    {"tof_data_rows", &MexFunction::tofDataRows},
    {"tof_data_cols", &MexFunction::tofDataCols},
    {"tof_data_frame_count", &MexFunction::tofDataFrameCount},
    {"tof_data_frame_type", &MexFunction::tofDataFrameType},
    {"tof_data_frame_id", &MexFunction::tofDataFrameId},
    {"tof_data_modulation_frequency", &MexFunction::tofDataModulationFrequency},
    {"tof_data_integration_time", &MexFunction::tofDataIntegrationTime},
    {"tof_data_process", &MexFunction::tofDataProcess},
    {"tof_data_scale", &MexFunction::tofDataScale},
    {"tof_data_addition", &MexFunction::tofDataAddition},
    {"tof_data_temperatures", &MexFunction::tofDataTemperatures},
    {"tof_data_sync_count", &MexFunction::tofDataSyncCount},
    {"tof_data_user_allocated", &MexFunction::tofDataUserAllocated},
    {"tof_data_user_pointer", &MexFunction::tofDataUserPointer},
    {"tof_csf_reader_delete", &MexFunction::tofCsfReaderDelete},
    {"tof_csf_reader_new", &MexFunction::tofCsfReaderNew},
    {"tof_csf_reader_read_frame", &MexFunction::tofCsfReaderReadFrame},
    {"tof_csf_reader_number_of_frames", &MexFunction::tofCsfReaderNumberOfFrames},
    {"tof_csf_reader_get_header", &MexFunction::tofCsfReaderGetHeader},
    {"tof_csf_reader_next_stream", &MexFunction::tofCsfReaderNextStream},
    {"tof_csf_reader_next_frame_size", &MexFunction::tofCsfReaderNextFrameSize},
    {"tof_csf_reader_frame_index", &MexFunction::tofCsfReaderFrameIndex},
    {"tof_csf_reader_go_to_frame", &MexFunction::tofCsfReaderGoToFrame},
    {"tof_csf_reader_streams", &MexFunction::tofCsfReaderStreams},
    {"tof_csf_reader_stream_count", &MexFunction::tofCsfReaderStreamCount},
    {"tof_csf_reader_go_to_stream", &MexFunction::tofCsfReaderGoToStream},
    {"tof_csf_reader_get_calibration", &MexFunction::tofCsfReaderGetCalibration},
    {"tof_csf_reader_get_camera_config", &MexFunction::tofCsfReaderGetCameraConfig},
    {"tof_csf_writer_delete", &MexFunction::tofCsfWriterDelete},
    {"tof_csf_writer_new", &MexFunction::tofCsfWriterNew},
    {"tof_csf_writer_write_frame", &MexFunction::tofCsfWriterWriteFrame},
    {"tof_create_csf_writer_reader", &MexFunction::tofCreateCsfWriterReader},
    {"tof_create_csf_writer_camera", &MexFunction::tofCreateCsfWriterCamera},
    {"tof_create_csf_writer_gige_interface", &MexFunction::tofCreateCsfWriterGigeInterface},
    {"tof_create_csf_writer_usb_interface", &MexFunction::tofCreateCsfWriterUsbInterface},
    {"tof_user_config_delete", &MexFunction::tofUserConfigDelete},
    {"tof_user_config_new_default", &MexFunction::tofUserConfigNewDefault},
    {"tof_user_config_to_camera_config", &MexFunction::tofUserConfigToCameraConfig},
    {"tof_user_config_get_environment", &MexFunction::tofUserConfigGetEnvironment},
    {"tof_user_config_set_environment", &MexFunction::tofUserConfigSetEnvironment},
    {"tof_user_config_get_max_distance", &MexFunction::tofUserConfigGetMaxDistance},
    {"tof_user_config_set_max_distance", &MexFunction::tofUserConfigSetMaxDistance},
    {"tof_user_config_get_fps", &MexFunction::tofUserConfigGetFps},
    {"tof_user_config_set_fps", &MexFunction::tofUserConfigSetFps},
    {"tof_user_config_get_lens_flare", &MexFunction::tofUserConfigGetLensFlare},
    {"tof_user_config_set_lens_flare", &MexFunction::tofUserConfigSetLensFlare},
    {"tof_user_config_get_translucent", &MexFunction::tofUserConfigGetTranslucent},
    {"tof_user_config_set_translucent", &MexFunction::tofUserConfigSetTranslucent},
    {"tof_user_config_get_hdr", &MexFunction::tofUserConfigGetHdr},
    {"tof_user_config_set_hdr", &MexFunction::tofUserConfigSetHdr},
    {"tof_user_config_get_integration_time", &MexFunction::tofUserConfigGetIntegrationTime},
    {"tof_user_config_set_integration_time", &MexFunction::tofUserConfigSetIntegrationTime},
    {"tof_user_config_get_strategy", &MexFunction::tofUserConfigGetStrategy},
    {"tof_user_config_set_strategy", &MexFunction::tofUserConfigSetStrategy},
    {"tof_user_config_get_channel", &MexFunction::tofUserConfigGetChannel},
    {"tof_user_config_set_channel", &MexFunction::tofUserConfigSetChannel},
    {"tof_processing_config_delete", &MexFunction::tofProcessingConfigDelete},
    {"tof_processing_config_new_default", &MexFunction::tofProcessingConfigNewDefault},
    {"tof_processing_config_new_from_disk", &MexFunction::tofProcessingConfigNewFromDisk},
    {"tof_processing_config_write", &MexFunction::tofProcessingConfigWrite},
    {"tof_processing_config_get_gpu", &MexFunction::tofProcessingConfigGetGpu},
    {"tof_processing_config_set_gpu", &MexFunction::tofProcessingConfigSetGpu},
    {"tof_processing_config_get_calibration_enabled", &MexFunction::tofProcessingConfigGetCalibrationEnabled},
    {"tof_processing_config_set_calibration_enabled", &MexFunction::tofProcessingConfigSetCalibrationEnabled},
    {"tof_processing_config_get_phase_unwrapping_enabled", &MexFunction::tofProcessingConfigGetPhaseUnwrappingEnabled},
    {"tof_processing_config_set_phase_unwrapping_enabled", &MexFunction::tofProcessingConfigSetPhaseUnwrappingEnabled},
    {"tof_processing_config_get_phase_unwrapping_max_offset", &MexFunction::tofProcessingConfigGetPhaseUnwrappingMaxOffset},
    {"tof_processing_config_set_phase_unwrapping_max_offset", &MexFunction::tofProcessingConfigSetPhaseUnwrappingMaxOffset},
    {"tof_processing_config_get_mixed_pixel_enabled", &MexFunction::tofProcessingConfigGetMixedPixelEnabled},
    {"tof_processing_config_set_mixed_pixel_enabled", &MexFunction::tofProcessingConfigSetMixedPixelEnabled},
    {"tof_processing_config_get_mixed_pixel_lut_file", &MexFunction::tofProcessingConfigGetMixedPixelLutFile},
    {"tof_processing_config_set_mixed_pixel_lut_file", &MexFunction::tofProcessingConfigSetMixedPixelLutFile},
    {"tof_processing_config_get_mixed_pixel_amp_min", &MexFunction::tofProcessingConfigGetMixedPixelAmpMin},
    {"tof_processing_config_set_mixed_pixel_amp_min", &MexFunction::tofProcessingConfigSetMixedPixelAmpMin},
    {"tof_processing_config_get_mixed_pixel_sort_mode", &MexFunction::tofProcessingConfigGetMixedPixelSortMode},
    {"tof_processing_config_set_mixed_pixel_sort_mode", &MexFunction::tofProcessingConfigSetMixedPixelSortMode},
    {"tof_processing_config_get_mixed_pixel_aratio", &MexFunction::tofProcessingConfigGetMixedPixelAratio},
    {"tof_processing_config_set_mixed_pixel_aratio", &MexFunction::tofProcessingConfigSetMixedPixelAratio},
    {"tof_processing_config_get_mixed_pixel_phi_diff", &MexFunction::tofProcessingConfigGetMixedPixelPhiDiff},
    {"tof_processing_config_set_mixed_pixel_phi_diff", &MexFunction::tofProcessingConfigSetMixedPixelPhiDiff},
    {"tof_processing_config_get_mixed_pixel_aggressor_threshold", &MexFunction::tofProcessingConfigGetMixedPixelAggressorThreshold},
    {"tof_processing_config_set_mixed_pixel_aggressor_threshold", &MexFunction::tofProcessingConfigSetMixedPixelAggressorThreshold},
    {"tof_processing_config_get_mixed_pixel_min_aggressor_size", &MexFunction::tofProcessingConfigGetMixedPixelMinAggressorSize},
    {"tof_processing_config_set_mixed_pixel_min_aggressor_size", &MexFunction::tofProcessingConfigSetMixedPixelMinAggressorSize},
    {"tof_processing_config_get_mixed_pixel_max_error_3f", &MexFunction::tofProcessingConfigGetMixedPixelMaxError3f},
    {"tof_processing_config_set_mixed_pixel_max_error_3f", &MexFunction::tofProcessingConfigSetMixedPixelMaxError3f},
    {"tof_processing_config_get_mixed_pixel_adaptive_amp_max", &MexFunction::tofProcessingConfigGetMixedPixelAdaptiveAmpMax},
    {"tof_processing_config_set_mixed_pixel_adaptive_amp_max", &MexFunction::tofProcessingConfigSetMixedPixelAdaptiveAmpMax},
    {"tof_processing_config_get_mixed_pixel_adaptive_amp_min", &MexFunction::tofProcessingConfigGetMixedPixelAdaptiveAmpMin},
    {"tof_processing_config_set_mixed_pixel_adaptive_amp_min", &MexFunction::tofProcessingConfigSetMixedPixelAdaptiveAmpMin},
    {"tof_processing_config_get_mixed_pixel_aratio_min", &MexFunction::tofProcessingConfigGetMixedPixelAratioMin},
    {"tof_processing_config_set_mixed_pixel_aratio_min", &MexFunction::tofProcessingConfigSetMixedPixelAratioMin},
    {"tof_processing_config_get_mixed_pixel_aggressor_phi_offset", &MexFunction::tofProcessingConfigGetMixedPixelAggressorPhiOffset},
    {"tof_processing_config_set_mixed_pixel_aggressor_phi_offset", &MexFunction::tofProcessingConfigSetMixedPixelAggressorPhiOffset},
    {"tof_processing_config_get_hdr_enabled", &MexFunction::tofProcessingConfigGetHdrEnabled},
    {"tof_processing_config_set_hdr_enabled", &MexFunction::tofProcessingConfigSetHdrEnabled},
    {"tof_processing_config_get_average_enabled", &MexFunction::tofProcessingConfigGetAverageEnabled},
    {"tof_processing_config_set_average_enabled", &MexFunction::tofProcessingConfigSetAverageEnabled},
    {"tof_processing_config_get_average_nframes", &MexFunction::tofProcessingConfigGetAverageNframes},
    {"tof_processing_config_set_average_nframes", &MexFunction::tofProcessingConfigSetAverageNframes},
    {"tof_processing_config_get_temporal_enabled", &MexFunction::tofProcessingConfigGetTemporalEnabled},
    {"tof_processing_config_set_temporal_enabled", &MexFunction::tofProcessingConfigSetTemporalEnabled},
    {"tof_processing_config_get_temporal_sigma", &MexFunction::tofProcessingConfigGetTemporalSigma},
    {"tof_processing_config_set_temporal_sigma", &MexFunction::tofProcessingConfigSetTemporalSigma},
    {"tof_processing_config_get_temporal_nframes", &MexFunction::tofProcessingConfigGetTemporalNframes},
    {"tof_processing_config_set_temporal_nframes", &MexFunction::tofProcessingConfigSetTemporalNframes},
    {"tof_processing_config_get_gaussian_enabled", &MexFunction::tofProcessingConfigGetGaussianEnabled},
    {"tof_processing_config_set_gaussian_enabled", &MexFunction::tofProcessingConfigSetGaussianEnabled},
    {"tof_processing_config_get_gaussian_size", &MexFunction::tofProcessingConfigGetGaussianSize},
    {"tof_processing_config_set_gaussian_size", &MexFunction::tofProcessingConfigSetGaussianSize},
    {"tof_processing_config_get_gaussian_sigma", &MexFunction::tofProcessingConfigGetGaussianSigma},
    {"tof_processing_config_set_gaussian_sigma", &MexFunction::tofProcessingConfigSetGaussianSigma},
    {"tof_processing_config_get_median_enabled", &MexFunction::tofProcessingConfigGetMedianEnabled},
    {"tof_processing_config_set_median_enabled", &MexFunction::tofProcessingConfigSetMedianEnabled},
    {"tof_processing_config_get_median_size", &MexFunction::tofProcessingConfigGetMedianSize},
    {"tof_processing_config_set_median_size", &MexFunction::tofProcessingConfigSetMedianSize},
    {"tof_processing_config_get_bilateral_enabled", &MexFunction::tofProcessingConfigGetBilateralEnabled},
    {"tof_processing_config_set_bilateral_enabled", &MexFunction::tofProcessingConfigSetBilateralEnabled},
    {"tof_processing_config_get_bilateral_size", &MexFunction::tofProcessingConfigGetBilateralSize},
    {"tof_processing_config_set_bilateral_size", &MexFunction::tofProcessingConfigSetBilateralSize},
    {"tof_processing_config_get_bilateral_sigma", &MexFunction::tofProcessingConfigGetBilateralSigma},
    {"tof_processing_config_set_bilateral_sigma", &MexFunction::tofProcessingConfigSetBilateralSigma},
    {"tof_processing_config_get_local_means_enabled", &MexFunction::tofProcessingConfigGetLocalMeansEnabled},
    {"tof_processing_config_set_local_means_enabled", &MexFunction::tofProcessingConfigSetLocalMeansEnabled},
    {"tof_processing_config_get_local_means_size", &MexFunction::tofProcessingConfigGetLocalMeansSize},
    {"tof_processing_config_set_local_means_size", &MexFunction::tofProcessingConfigSetLocalMeansSize},
    {"tof_processing_config_get_local_means_sigma", &MexFunction::tofProcessingConfigGetLocalMeansSigma},
    {"tof_processing_config_set_local_means_sigma", &MexFunction::tofProcessingConfigSetLocalMeansSigma},
    {"tof_processing_config_get_flying_enabled", &MexFunction::tofProcessingConfigGetFlyingEnabled},
    {"tof_processing_config_set_flying_enabled", &MexFunction::tofProcessingConfigSetFlyingEnabled},
    {"tof_processing_config_get_flying_shape", &MexFunction::tofProcessingConfigGetFlyingShape},
    {"tof_processing_config_set_flying_shape", &MexFunction::tofProcessingConfigSetFlyingShape},
    {"tof_processing_config_get_flying_distance", &MexFunction::tofProcessingConfigGetFlyingDistance},
    {"tof_processing_config_set_flying_distance", &MexFunction::tofProcessingConfigSetFlyingDistance},
    {"tof_processing_config_get_flying_edges", &MexFunction::tofProcessingConfigGetFlyingEdges},
    {"tof_processing_config_set_flying_edges", &MexFunction::tofProcessingConfigSetFlyingEdges},
    {"tof_processing_config_get_amp_threshold_enabled", &MexFunction::tofProcessingConfigGetAmpThresholdEnabled},
    {"tof_processing_config_set_amp_threshold_enabled", &MexFunction::tofProcessingConfigSetAmpThresholdEnabled},
    {"tof_processing_config_get_amp_threshold_min", &MexFunction::tofProcessingConfigGetAmpThresholdMin},
    {"tof_processing_config_set_amp_threshold_min", &MexFunction::tofProcessingConfigSetAmpThresholdMin},
    {"tof_processing_config_get_amp_threshold_max", &MexFunction::tofProcessingConfigGetAmpThresholdMax},
    {"tof_processing_config_set_amp_threshold_max", &MexFunction::tofProcessingConfigSetAmpThresholdMax},
    {"tof_processing_config_get_dist_threshold_enabled", &MexFunction::tofProcessingConfigGetDistThresholdEnabled},
    {"tof_processing_config_set_dist_threshold_enabled", &MexFunction::tofProcessingConfigSetDistThresholdEnabled},
    {"tof_processing_config_get_dist_threshold_min", &MexFunction::tofProcessingConfigGetDistThresholdMin},
    {"tof_processing_config_set_dist_threshold_min", &MexFunction::tofProcessingConfigSetDistThresholdMin},
    {"tof_processing_config_get_dist_threshold_max", &MexFunction::tofProcessingConfigGetDistThresholdMax},
    {"tof_processing_config_set_dist_threshold_max", &MexFunction::tofProcessingConfigSetDistThresholdMax},
    {"tof_processing_config_get_radial_scale", &MexFunction::tofProcessingConfigGetRadialScale},
    {"tof_processing_config_set_radial_scale", &MexFunction::tofProcessingConfigSetRadialScale},
    {"tof_processing_config_get_radial_add", &MexFunction::tofProcessingConfigGetRadialAdd},
    {"tof_processing_config_set_radial_add", &MexFunction::tofProcessingConfigSetRadialAdd},
    {"tof_processing_config_get_intensity_scale", &MexFunction::tofProcessingConfigGetIntensityScale},
    {"tof_processing_config_set_intensity_scale", &MexFunction::tofProcessingConfigSetIntensityScale},
    {"tof_processing_config_get_intensity_add", &MexFunction::tofProcessingConfigGetIntensityAdd},
    {"tof_processing_config_set_intensity_add", &MexFunction::tofProcessingConfigSetIntensityAdd},
    {"tof_processing_config_get_char_add", &MexFunction::tofProcessingConfigGetCharAdd},
    {"tof_processing_config_set_char_add", &MexFunction::tofProcessingConfigSetCharAdd},
    {"tof_processing_config_get_char_mult", &MexFunction::tofProcessingConfigGetCharMult},
    {"tof_processing_config_set_char_mult", &MexFunction::tofProcessingConfigSetCharMult},
    {"tof_processing_config_get_binning_enabled", &MexFunction::tofProcessingConfigGetBinningEnabled},
    {"tof_processing_config_set_binning_enabled", &MexFunction::tofProcessingConfigSetBinningEnabled},
    {"tof_processing_config_get_binning_size", &MexFunction::tofProcessingConfigGetBinningSize},
    {"tof_processing_config_set_binning_size", &MexFunction::tofProcessingConfigSetBinningSize},
    {"tof_processing_config_get_binning_mode", &MexFunction::tofProcessingConfigGetBinningMode},
    {"tof_processing_config_set_binning_mode", &MexFunction::tofProcessingConfigSetBinningMode},
    {"tof_processing_config_get_binning_sigma", &MexFunction::tofProcessingConfigGetBinningSigma},
    {"tof_processing_config_set_binning_sigma", &MexFunction::tofProcessingConfigSetBinningSigma},
    {"tof_processing_config_get_xyz_dimension", &MexFunction::tofProcessingConfigGetXyzDimension},
    {"tof_processing_config_set_xyz_dimension", &MexFunction::tofProcessingConfigSetXyzDimension},
    {"tof_processing_config_get_rigid_transformation_enabled", &MexFunction::tofProcessingConfigGetRigidTransformationEnabled},
    {"tof_processing_config_set_rigid_transformation_enabled", &MexFunction::tofProcessingConfigSetRigidTransformationEnabled},
    {"tof_processing_config_get_rigid_transformation_matrix", &MexFunction::tofProcessingConfigGetRigidTransformationMatrix},
    {"tof_processing_config_set_rigid_transformation_matrix", &MexFunction::tofProcessingConfigSetRigidTransformationMatrix},
    {"tof_roi_delete", &MexFunction::tofRoiDelete},
    {"tof_roi_sensor_rows", &MexFunction::tofRoiSensorRows},
    {"tof_roi_sensor_cols", &MexFunction::tofRoiSensorCols},
    {"tof_roi_get_row_offset", &MexFunction::tofRoiGetRowOffset},
    {"tof_roi_set_row_offset", &MexFunction::tofRoiSetRowOffset},
    {"tof_roi_get_col_offset", &MexFunction::tofRoiGetColOffset},
    {"tof_roi_set_col_offset", &MexFunction::tofRoiSetColOffset},
    {"tof_roi_get_img_rows", &MexFunction::tofRoiGetImgRows},
    {"tof_roi_set_img_rows", &MexFunction::tofRoiSetImgRows},
    {"tof_roi_get_img_cols", &MexFunction::tofRoiGetImgCols},
    {"tof_roi_set_img_cols", &MexFunction::tofRoiSetImgCols},
    {"tof_camera_config_delete", &MexFunction::tofCameraConfigDelete},
    {"tof_camera_config_new_from_disk", &MexFunction::tofCameraConfigNewFromDisk},
    {"tof_camera_config_write", &MexFunction::tofCameraConfigWrite},
    {"tof_camera_config_get_type", &MexFunction::tofCameraConfigGetType},
    {"tof_camera_config_reset", &MexFunction::tofCameraConfigReset},
    {"tof_camera_config_frame_size", &MexFunction::tofCameraConfigFrameSize},
    {"tof_camera_config_add_frame", &MexFunction::tofCameraConfigAddFrame},
    {"tof_camera_config_default_processing", &MexFunction::tofCameraConfigDefaultProcessing},
    {"tof_camera_config_erase_frame", &MexFunction::tofCameraConfigEraseFrame},
    {"tof_camera_config_get_phase_shifts", &MexFunction::tofCameraConfigGetPhaseShifts},
    {"tof_camera_config_set_phase_shifts", &MexFunction::tofCameraConfigSetPhaseShifts},
    {"tof_camera_config_get_integration_time", &MexFunction::tofCameraConfigGetIntegrationTime},
    {"tof_camera_config_set_integration_time", &MexFunction::tofCameraConfigSetIntegrationTime},
    {"tof_camera_config_get_sensor_mode", &MexFunction::tofCameraConfigGetSensorMode},
    {"tof_camera_config_set_sensor_mode", &MexFunction::tofCameraConfigSetSensorMode},
    {"tof_camera_config_get_modulation_frequency", &MexFunction::tofCameraConfigGetModulationFrequency},
    {"tof_camera_config_set_modulation_frequency", &MexFunction::tofCameraConfigSetModulationFrequency},
    {"tof_camera_config_get_duty_cycle", &MexFunction::tofCameraConfigGetDutyCycle},
    {"tof_camera_config_set_duty_cycle", &MexFunction::tofCameraConfigSetDutyCycle},
    {"tof_camera_config_get_roi", &MexFunction::tofCameraConfigGetRoi},
    {"tof_camera_config_set_roi", &MexFunction::tofCameraConfigSetRoi},
    {"tof_camera_config_get_binning", &MexFunction::tofCameraConfigGetBinning},
    {"tof_camera_config_set_binning", &MexFunction::tofCameraConfigSetBinning},
    {"tof_camera_config_get_flip", &MexFunction::tofCameraConfigGetFlip},
    {"tof_camera_config_set_flip", &MexFunction::tofCameraConfigSetFlip},
    {"tof_camera_config_get_mirror", &MexFunction::tofCameraConfigGetMirror},
    {"tof_camera_config_set_mirror", &MexFunction::tofCameraConfigSetMirror},
    {"tof_camera_config_get_gain", &MexFunction::tofCameraConfigGetGain},
    {"tof_camera_config_set_gain", &MexFunction::tofCameraConfigSetGain},
    {"tof_camera_config_get_sync_mode", &MexFunction::tofCameraConfigGetSyncMode},
    {"tof_camera_config_set_sync_mode", &MexFunction::tofCameraConfigSetSyncMode},
    {"tof_camera_config_maximum_integration_time", &MexFunction::tofCameraConfigMaximumIntegrationTime},
    {"tof_camera_config_get_dac", &MexFunction::tofCameraConfigGetDac},
    {"tof_camera_config_set_dac", &MexFunction::tofCameraConfigSetDac},
    {"tof_camera_config_get_mlx_mipi_speed", &MexFunction::tofCameraConfigGetMlxMipiSpeed},
    {"tof_camera_config_set_mlx_mipi_speed", &MexFunction::tofCameraConfigSetMlxMipiSpeed},
    {"tof_camera_config_get_mlx_preheat", &MexFunction::tofCameraConfigGetMlxPreheat},
    {"tof_camera_config_set_mlx_preheat", &MexFunction::tofCameraConfigSetMlxPreheat},
    {"tof_camera_config_get_mlx_preheat_enable", &MexFunction::tofCameraConfigGetMlxPreheatEnable},
    {"tof_camera_config_set_mlx_preheat_enable", &MexFunction::tofCameraConfigSetMlxPreheatEnable},
    {"tof_camera_config_set_opt_kea_nios_hex", &MexFunction::tofCameraConfigSetOptKeaNiosHex},
    {"tof_camera_config_get_opt_kea_sub_quad", &MexFunction::tofCameraConfigGetOptKeaSubQuad},
    {"tof_camera_config_set_opt_kea_sub_quad", &MexFunction::tofCameraConfigSetOptKeaSubQuad},
    {"tof_camera_config_get_processing", &MexFunction::tofCameraConfigGetProcessing},
    {"tof_camera_config_set_processing", &MexFunction::tofCameraConfigSetProcessing},
    {"tof_camera_config_get_frame_time", &MexFunction::tofCameraConfigGetFrameTime},
    {"tof_camera_config_set_frame_time", &MexFunction::tofCameraConfigSetFrameTime},
    {"tof_camera_config_get_global_phase_offset", &MexFunction::tofCameraConfigGetGlobalPhaseOffset},
    {"tof_camera_config_set_global_phase_offset", &MexFunction::tofCameraConfigSetGlobalPhaseOffset},
    {"tof_camera_config_get_illumination_mode", &MexFunction::tofCameraConfigGetIlluminationMode},
    {"tof_camera_config_set_illumination_mode", &MexFunction::tofCameraConfigSetIlluminationMode},
    {"tof_camera_config_get_image_offsets", &MexFunction::tofCameraConfigGetImageOffsets},
    {"tof_camera_config_set_image_offsets", &MexFunction::tofCameraConfigSetImageOffsets},
    {"tof_camera_config_get_rgb_width", &MexFunction::tofCameraConfigGetRgbWidth},
    {"tof_camera_config_get_rgb_height", &MexFunction::tofCameraConfigGetRgbHeight},
    {"tof_camera_config_get_trigger_mode", &MexFunction::tofCameraConfigGetTriggerMode},
    {"tof_camera_config_set_trigger_mode", &MexFunction::tofCameraConfigSetTriggerMode},
    {"tof_calibration_delete", &MexFunction::tofCalibrationDelete},
    {"tof_calibration_new_from_disk", &MexFunction::tofCalibrationNewFromDisk},
    {"tof_calibration_write", &MexFunction::tofCalibrationWrite},
    {"tof_calibration_get_calibrated_frequencies", &MexFunction::tofCalibrationGetCalibratedFrequencies},
    {"tof_calibration_get_focal_length_x", &MexFunction::tofCalibrationGetFocalLengthX},
    {"tof_calibration_get_focal_length_y", &MexFunction::tofCalibrationGetFocalLengthY},
    {"tof_calibration_get_principal_point_x", &MexFunction::tofCalibrationGetPrincipalPointX},
    {"tof_calibration_get_principal_point_y", &MexFunction::tofCalibrationGetPrincipalPointY},
    {"tof_calibration_get_depth_camera_matrix", &MexFunction::tofCalibrationGetDepthCameraMatrix},
    {"tof_calibration_get_depth_distortion_coefficients", &MexFunction::tofCalibrationGetDepthDistortionCoefficients},
    {"tof_calibration_get_rgb_camera_matrix", &MexFunction::tofCalibrationGetRgbCameraMatrix},
    {"tof_calibration_get_rgb_distortion_coefficients", &MexFunction::tofCalibrationGetRgbDistortionCoefficients},
    {"tof_calibration_get_rotation_vector", &MexFunction::tofCalibrationGetRotationVector},
    {"tof_calibration_get_translation_vector", &MexFunction::tofCalibrationGetTranslationVector},
    {"tof_camera_delete", &MexFunction::tofCameraDelete},
    {"tof_camera_start", &MexFunction::tofCameraStart},
    {"tof_camera_stop", &MexFunction::tofCameraStop},
    {"tof_camera_is_streaming", &MexFunction::tofCameraIsStreaming},
    {"tof_camera_is_connected", &MexFunction::tofCameraIsConnected},
    {"tof_camera_get_stream_list", &MexFunction::tofCameraGetStreamList},
    {"tof_camera_set_stream_list", &MexFunction::tofCameraSetStreamList},
    {"tof_camera_is_stream_list_set", &MexFunction::tofCameraIsStreamListSet},
    {"tof_camera_get_set_stream_list", &MexFunction::tofCameraGetSetStreamList},
    {"tof_camera_get_process_config", &MexFunction::tofCameraGetProcessConfig},
    {"tof_camera_set_process_config", &MexFunction::tofCameraSetProcessConfig},
    {"tof_camera_has_frames", &MexFunction::tofCameraHasFrames},
    {"tof_camera_get_frames", &MexFunction::tofCameraGetFrames},
    {"tof_camera_clear_buffer", &MexFunction::tofCameraClearBuffer},
    {"tof_camera_get_buffer_size", &MexFunction::tofCameraGetBufferSize},
    {"tof_camera_set_buffer_size", &MexFunction::tofCameraSetBufferSize},
    {"tof_camera_get_camera_config", &MexFunction::tofCameraGetCameraConfig},
    {"tof_camera_get_serial", &MexFunction::tofCameraGetSerial},
    {"tof_camera_get_calibration", &MexFunction::tofCameraGetCalibration},
    {"tof_camera_get_user_pointer_capacity", &MexFunction::tofCameraGetUserPointerCapacity},
    {"tof_camera_set_user_pointer_capacity", &MexFunction::tofCameraSetUserPointerCapacity},
    {"tof_camera_clear_user_pointers", &MexFunction::tofCameraClearUserPointers},
    {"tof_select_streams", &MexFunction::tofSelectStreams},
    {"tof_select_streams_mod_freq", &MexFunction::tofSelectStreamsModFreq},
    {"tof_kea_camera_delete", &MexFunction::tofKeaCameraDelete},
    {"tof_kea_camera_new", &MexFunction::tofKeaCameraNew},
    {"tof_kea_camera_on_camera_processing_capable", &MexFunction::tofKeaCameraOnCameraProcessingCapable},
    {"tof_kea_camera_get_on_camera_processing", &MexFunction::tofKeaCameraGetOnCameraProcessing},
    {"tof_kea_camera_set_on_camera_processing", &MexFunction::tofKeaCameraSetOnCameraProcessing},
    {"tof_kea_camera_get_delay", &MexFunction::tofKeaCameraGetDelay},
    {"tof_kea_camera_set_delay", &MexFunction::tofKeaCameraSetDelay},
    {"tof_kea_camera_get_packet_size", &MexFunction::tofKeaCameraGetPacketSize},
    {"tof_kea_camera_set_packet_size", &MexFunction::tofKeaCameraSetPacketSize},
    {"tof_kea_camera_set_camera_config", &MexFunction::tofKeaCameraSetCameraConfig},
    {"tof_kea_camera_set_configurations", &MexFunction::tofKeaCameraSetConfigurations},
    {"tof_kea_camera_version", &MexFunction::tofKeaCameraVersion},
    {"tof_kea_camera_software_trigger_capable", &MexFunction::tofKeaCameraSoftwareTriggerCapable},
    {"tof_kea_camera_software_trigger", &MexFunction::tofKeaCameraSoftwareTrigger},
    {"tof_kea_camera_remote_update_capable", &MexFunction::tofKeaCameraRemoteUpdateCapable},
    {"tof_kea_camera_remote_update", &MexFunction::tofKeaCameraRemoteUpdate},
    {"tof_discovered_kea_delete", &MexFunction::tofDiscoveredKeaDelete},
    {"tof_discovered_kea_serial", &MexFunction::tofDiscoveredKeaSerial},
    {"tof_discovered_kea_info", &MexFunction::tofDiscoveredKeaInfo},
    {"tof_discover_kea_cameras", &MexFunction::tofDiscoverKeaCameras},
    {"tof_create_kea_camera_gige", &MexFunction::tofCreateKeaCameraGige},
    {"tof_crash_report_delete", &MexFunction::tofCrashReportDelete},
    {"tof_crash_report_new", &MexFunction::tofCrashReportNew},
    {"tof_crash_report_get_description", &MexFunction::tofCrashReportGetDescription},
    {"tof_crash_report_set_description", &MexFunction::tofCrashReportSetDescription},
    {"tof_crash_report_get_report", &MexFunction::tofCrashReportGetReport},
    {"tof_crash_report_save", &MexFunction::tofCrashReportSave},
    {"tof_get_version", &MexFunction::tofGetVersion},
    {"tof_log_to_console", &MexFunction::tofLogToConsole},
    {"tof_log_to_file", &MexFunction::tofLogToFile},
    {"tof_log_drop", &MexFunction::tofLogDrop},
    {"tof_csf_camera_delete", &MexFunction::tofCsfCameraDelete},
    {"tof_csf_camera_new", &MexFunction::tofCsfCameraNew},
    {"tof_csf_camera_get_frames_at", &MexFunction::tofCsfCameraGetFramesAt},
    {"tof_csf_camera_get_current_frame", &MexFunction::tofCsfCameraGetCurrentFrame},
    {"tof_csf_camera_get_frame_number", &MexFunction::tofCsfCameraGetFrameNumber},
    {"tof_csf_camera_get_fps", &MexFunction::tofCsfCameraGetFps},
    {"tof_csf_camera_set_fps", &MexFunction::tofCsfCameraSetFps},
    {"tof_discovery_message_delete", &MexFunction::tofDiscoveryMessageDelete},
    {"tof_discovery_message_ip", &MexFunction::tofDiscoveryMessageIp},
    {"tof_discovery_message_serial", &MexFunction::tofDiscoveryMessageSerial},
    {"tof_persistent_ip_delete", &MexFunction::tofPersistentIpDelete},
    {"tof_persistent_ip_new", &MexFunction::tofPersistentIpNew},
    {"tof_persistent_ip_get_ip", &MexFunction::tofPersistentIpGetIp},
    {"tof_persistent_ip_set_ip", &MexFunction::tofPersistentIpSetIp},
    {"tof_persistent_ip_get_netmask", &MexFunction::tofPersistentIpGetNetmask},
    {"tof_persistent_ip_set_netmask", &MexFunction::tofPersistentIpSetNetmask},
    {"tof_persistent_ip_get_gateway", &MexFunction::tofPersistentIpGetGateway},
    {"tof_persistent_ip_set_gateway", &MexFunction::tofPersistentIpSetGateway},
    {"tof_persistent_ip_get_enabled", &MexFunction::tofPersistentIpGetEnabled},
    {"tof_persistent_ip_set_enabled", &MexFunction::tofPersistentIpSetEnabled},
    {"tof_gige_interface_delete", &MexFunction::tofGigeInterfaceDelete},
    {"tof_gige_interface_new", &MexFunction::tofGigeInterfaceNew},
    {"tof_gige_interface_discover", &MexFunction::tofGigeInterfaceDiscover},
    {"tof_gige_interface_discover_one", &MexFunction::tofGigeInterfaceDiscoverOne},
    {"tof_gige_interface_find", &MexFunction::tofGigeInterfaceFind},
    {"tof_gige_interface_connect", &MexFunction::tofGigeInterfaceConnect},
    {"tof_gige_interface_disconnect", &MexFunction::tofGigeInterfaceDisconnect},
    {"tof_gige_interface_is_connected", &MexFunction::tofGigeInterfaceIsConnected},
    {"tof_gige_interface_get_stream_packet_size", &MexFunction::tofGigeInterfaceGetStreamPacketSize},
    {"tof_gige_interface_set_stream_packet_size", &MexFunction::tofGigeInterfaceSetStreamPacketSize},
    {"tof_gige_interface_test_stream_packet_size", &MexFunction::tofGigeInterfaceTestStreamPacketSize},
    {"tof_gige_interface_get_delay", &MexFunction::tofGigeInterfaceGetDelay},
    {"tof_gige_interface_set_delay", &MexFunction::tofGigeInterfaceSetDelay},
    {"tof_gige_interface_download_configuration", &MexFunction::tofGigeInterfaceDownloadConfiguration},
    {"tof_gige_interface_download_calibration", &MexFunction::tofGigeInterfaceDownloadCalibration},
    {"tof_gige_interface_upload_configuration", &MexFunction::tofGigeInterfaceUploadConfiguration},
    {"tof_gige_interface_depth_stream_capable", &MexFunction::tofGigeInterfaceDepthStreamCapable},
    {"tof_gige_interface_start_depth_stream", &MexFunction::tofGigeInterfaceStartDepthStream},
    {"tof_gige_interface_stop_depth_stream", &MexFunction::tofGigeInterfaceStopDepthStream},
    {"tof_gige_interface_has_depth_data", &MexFunction::tofGigeInterfaceHasDepthData},
    {"tof_gige_interface_get_depth_data", &MexFunction::tofGigeInterfaceGetDepthData},
    {"tof_gige_interface_image_stream_capable", &MexFunction::tofGigeInterfaceImageStreamCapable},
    {"tof_gige_interface_start_image_stream", &MexFunction::tofGigeInterfaceStartImageStream},
    {"tof_gige_interface_stop_image_stream", &MexFunction::tofGigeInterfaceStopImageStream},
    {"tof_gige_interface_has_image_data", &MexFunction::tofGigeInterfaceHasImageData},
    {"tof_gige_interface_get_image_data", &MexFunction::tofGigeInterfaceGetImageData},
    {"tof_gige_interface_persistent_ip_capable", &MexFunction::tofGigeInterfacePersistentIpCapable},
    {"tof_gige_interface_get_persistent_ip", &MexFunction::tofGigeInterfaceGetPersistentIp},
    {"tof_gige_interface_set_persistent_ip", &MexFunction::tofGigeInterfaceSetPersistentIp},
    {"tof_gige_interface_get_user_pointer_capacity", &MexFunction::tofGigeInterfaceGetUserPointerCapacity},
    {"tof_gige_interface_set_user_pointer_capacity", &MexFunction::tofGigeInterfaceSetUserPointerCapacity},
    {"tof_gige_interface_version", &MexFunction::tofGigeInterfaceVersion},
    {"tof_gige_interface_software_trigger_capable", &MexFunction::tofGigeInterfaceSoftwareTriggerCapable},
    {"tof_gige_interface_software_trigger", &MexFunction::tofGigeInterfaceSoftwareTrigger},
    {"tof_usb_device_delete", &MexFunction::tofUsbDeviceDelete},
    {"tof_usb_device_serial", &MexFunction::tofUsbDeviceSerial},
    {"tof_usb_interface_delete", &MexFunction::tofUsbInterfaceDelete},
    {"tof_usb_interface_new", &MexFunction::tofUsbInterfaceNew},
    {"tof_usb_interface_is_connected", &MexFunction::tofUsbInterfaceIsConnected},
    {"tof_usb_interface_test_stream_speed", &MexFunction::tofUsbInterfaceTestStreamSpeed},
    {"tof_usb_interface_download_configuration", &MexFunction::tofUsbInterfaceDownloadConfiguration},
    {"tof_usb_interface_download_calibration", &MexFunction::tofUsbInterfaceDownloadCalibration},
    {"tof_usb_interface_upload_configuration", &MexFunction::tofUsbInterfaceUploadConfiguration},
    {"tof_usb_interface_depth_stream_capable", &MexFunction::tofUsbInterfaceDepthStreamCapable},
    {"tof_usb_interface_start_depth_stream", &MexFunction::tofUsbInterfaceStartDepthStream},
    {"tof_usb_interface_stop_depth_stream", &MexFunction::tofUsbInterfaceStopDepthStream},
    {"tof_usb_interface_has_depth_data", &MexFunction::tofUsbInterfaceHasDepthData},
    {"tof_usb_interface_get_depth_data", &MexFunction::tofUsbInterfaceGetDepthData},
    {"tof_usb_interface_image_stream_capable", &MexFunction::tofUsbInterfaceImageStreamCapable},
    {"tof_usb_interface_start_image_stream", &MexFunction::tofUsbInterfaceStartImageStream},
    {"tof_usb_interface_stop_image_stream", &MexFunction::tofUsbInterfaceStopImageStream},
    {"tof_usb_interface_has_image_data", &MexFunction::tofUsbInterfaceHasImageData},
    {"tof_usb_interface_get_image_data", &MexFunction::tofUsbInterfaceGetImageData},
    {"tof_usb_interface_get_user_pointer_capacity", &MexFunction::tofUsbInterfaceGetUserPointerCapacity},
    {"tof_usb_interface_set_user_pointer_capacity", &MexFunction::tofUsbInterfaceSetUserPointerCapacity},
    {"tof_usb_interface_version", &MexFunction::tofUsbInterfaceVersion},
    {"tof_usb_interface_software_trigger_capable", &MexFunction::tofUsbInterfaceSoftwareTriggerCapable},
    {"tof_usb_interface_software_trigger", &MexFunction::tofUsbInterfaceSoftwareTrigger},
    {"tof_usb_device_discover", &MexFunction::tofUsbDeviceDiscover},
    {"tof_usb_device_discover_one", &MexFunction::tofUsbDeviceDiscoverOne},
    {"tof_usb_device_find", &MexFunction::tofUsbDeviceFind},
  };

  void tofStreamDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Stream");
    }

    auto stream = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_stream_delete(stream);
  }

  void tofStreamFrameType(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_stream_frame_type(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofStreamFrameId(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_stream_frame_id(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofStreamModulationFrequency(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_stream_modulation_frequency(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofStreamIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_stream_integration_time(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofStreamProcess(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_stream_process(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofFrameTypeToString(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT32) {
      error_("Input 2 must be FrameType");
    }

    uint32_t enum_1 = inputs[1][0];
    auto frame_type = static_cast<tof_frame_type>(enum_1);

    tof_error_t error{nullptr};

    const auto output = tof_frame_type_to_string(frame_type, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto data = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_data_delete(data);
  }

  void tofDataData(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofDataData(outputs, inputs, factory_);
  }

  void tofDataSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataGetUserData(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_get_user_data(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataSetUserData(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint64_t user_data = inputs[2][0];

    tof_error_t error{nullptr};

    tof_data_set_user_data(class_instance, user_data, &error);
    if (check_error_(error)) return;
  }

  void tofDataMatType(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_mat_type(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofDataRows(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_rows(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataCols(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_cols(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataFrameCount(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_frame_count(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataFrameType(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_frame_type(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofDataFrameId(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_frame_id(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataModulationFrequency(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_modulation_frequency(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_integration_time(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataProcess(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_process(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataScale(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_scale(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataAddition(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_addition(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataTemperatures(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_data_temperatures(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<float> temperatures(capacity);
    capacity = tof_data_temperatures(class_instance, temperatures.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, temperatures.data(), temperatures.data() + capacity);
  }

  void tofDataSyncCount(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_sync_count(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataUserAllocated(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_user_allocated(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDataUserPointer(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_data_user_pointer(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfReaderDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto csf_reader = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_csf_reader_delete(csf_reader);
  }

  void tofCsfReaderNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_new(file_location, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfReaderReadFrame(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofCsfReaderReadFrame(outputs, inputs, factory_);
  }

  void tofCsfReaderNumberOfFrames(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_number_of_frames(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfReaderGetHeader(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t index = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_get_header(class_instance, index, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfReaderNextStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_next_stream(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfReaderNextFrameSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_next_frame_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfReaderFrameIndex(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_frame_index(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfReaderGoToFrame(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t index = inputs[2][0];

    tof_error_t error{nullptr};

    tof_csf_reader_go_to_frame(class_instance, index, &error);
    if (check_error_(error)) return;
  }

  void tofCsfReaderStreams(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_csf_reader_streams(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_stream_t> streams(capacity);
    capacity = tof_csf_reader_streams(class_instance, streams.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : streams) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofCsfReaderStreamCount(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    auto stream = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_stream_count(class_instance, stream, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfReaderGoToStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be Stream");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    auto stream = reinterpret_cast<tof_stream_t>(static_cast<uint64_t>(inputs[2][0]));

    const size_t index = inputs[3][0];

    tof_error_t error{nullptr};

    tof_csf_reader_go_to_stream(class_instance, stream, index, &error);
    if (check_error_(error)) return;
  }

  void tofCsfReaderGetCalibration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_get_calibration(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfReaderGetCameraConfig(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfReader");
    }

    auto class_instance = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_reader_get_camera_config(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfWriterDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfWriter");
    }

    auto csf_writer = reinterpret_cast<tof_csf_writer_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_csf_writer_delete(csf_writer);
  }

  void tofCsfWriterNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 5 || outputs.size() != 1) {
      error_("5 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be CameraConfig");
    }

    if (inputs[3].getType() != data::ArrayType::UINT64) {
      error_("Input 4 must be Calibration");
    }

    if (inputs[4].getType() != data::ArrayType::CHAR &&
        inputs[4].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 5 must be a string");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    auto camera_config = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[2][0]));

    auto calibration = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[3][0]));

    std::string serial_str;
    if (inputs[4].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[4]);
      serial_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[4]);
      serial_str = string_array[0];
    }
    const char* serial = serial_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_csf_writer_new(file_location, camera_config, calibration, serial, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfWriterWriteFrame(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfWriter");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be Data");
    }

    auto class_instance = reinterpret_cast<tof_csf_writer_t>(static_cast<uint64_t>(inputs[1][0]));

    auto frame = reinterpret_cast<tof_data_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_csf_writer_write_frame(class_instance, frame, &error);
    if (check_error_(error)) return;
  }

  void tofCreateCsfWriterReader(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be CsfReader");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    auto reader = reinterpret_cast<tof_csf_reader_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    const auto output = tof_create_csf_writer_reader(file_location, reader, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCreateCsfWriterCamera(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be Camera");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    auto camera = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    const auto output = tof_create_csf_writer_camera(file_location, camera, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCreateCsfWriterGigeInterface(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be GigeInterface");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    auto gige_interface = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    const auto output = tof_create_csf_writer_gige_interface(file_location, gige_interface, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCreateCsfWriterUsbInterface(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be UsbInterface");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    auto usb_interface = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    const auto output = tof_create_csf_writer_usb_interface(file_location, usb_interface, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUserConfigDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto user_config = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_user_config_delete(user_config);
  }

  void tofUserConfigNewDefault(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 1) {
      error_("1 inputs are required and 1 outputs are returned");
    }

    tof_error_t error{nullptr};

    const auto output = tof_user_config_new_default(&error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUserConfigToCameraConfig(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    auto camera = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_to_camera_config(class_instance, camera, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUserConfigGetEnvironment(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_environment(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofUserConfigSetEnvironment(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be ImagingEnvironment");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto imaging_environment = static_cast<tof_imaging_environment>(enum_2);

    tof_error_t error{nullptr};

    tof_user_config_set_environment(class_instance, imaging_environment, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetMaxDistance(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_max_distance(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUserConfigSetMaxDistance(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float max_distance = inputs[2][0];

    tof_error_t error{nullptr};

    tof_user_config_set_max_distance(class_instance, max_distance, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetFps(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_fps(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUserConfigSetFps(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float fps = inputs[2][0];

    tof_error_t error{nullptr};

    tof_user_config_set_fps(class_instance, fps, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetLensFlare(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_lens_flare(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUserConfigSetLensFlare(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool lens_flare = inputs[2][0];

    tof_error_t error{nullptr};

    tof_user_config_set_lens_flare(class_instance, lens_flare, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetTranslucent(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_translucent(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUserConfigSetTranslucent(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool translucent = inputs[2][0];

    tof_error_t error{nullptr};

    tof_user_config_set_translucent(class_instance, translucent, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetHdr(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_hdr(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUserConfigSetHdr(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool hdr = inputs[2][0];

    tof_error_t error{nullptr};

    tof_user_config_set_hdr(class_instance, hdr, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_integration_time(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofUserConfigSetIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be IntegrationTime");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto int_time = static_cast<tof_integration_time>(enum_2);

    tof_error_t error{nullptr};

    tof_user_config_set_integration_time(class_instance, int_time, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetStrategy(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_strategy(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofUserConfigSetStrategy(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be Strategy");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto strategy = static_cast<tof_strategy>(enum_2);

    tof_error_t error{nullptr};

    tof_user_config_set_strategy(class_instance, strategy, &error);
    if (check_error_(error)) return;
  }

  void tofUserConfigGetChannel(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_user_config_get_channel(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUserConfigSetChannel(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UserConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_user_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t channel = inputs[2][0];

    tof_error_t error{nullptr};

    tof_user_config_set_channel(class_instance, channel, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto processing_config = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_processing_config_delete(processing_config);
  }

  void tofProcessingConfigNewDefault(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 1) {
      error_("1 inputs are required and 1 outputs are returned");
    }

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_new_default(&error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofProcessingConfigNewFromDisk(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_processing_config_new_from_disk(file_location, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofProcessingConfigWrite(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_processing_config_write(class_instance, file_location, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetGpu(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_gpu(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetGpu(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool gpu = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_gpu(class_instance, gpu, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetCalibrationEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_calibration_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetCalibrationEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_calibration_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetPhaseUnwrappingEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_phase_unwrapping_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetPhaseUnwrappingEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_phase_unwrapping_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetPhaseUnwrappingMaxOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_phase_unwrapping_max_offset(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetPhaseUnwrappingMaxOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double max_offset = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_phase_unwrapping_max_offset(class_instance, max_offset, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelLutFile(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_lut_file(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelLutFile(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_lut_file(class_instance, file_location, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAmpMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_amp_min(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAmpMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double amp_min = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_amp_min(class_instance, amp_min, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelSortMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_sort_mode(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofProcessingConfigSetMixedPixelSortMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be MpSortMode");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto sort_mode = static_cast<tof_mp_sort_mode>(enum_2);

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_sort_mode(class_instance, sort_mode, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAratio(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_aratio(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAratio(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double aratio = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_aratio(class_instance, aratio, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelPhiDiff(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_phi_diff(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelPhiDiff(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double phi_diff = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_phi_diff(class_instance, phi_diff, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAggressorThreshold(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_aggressor_threshold(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAggressorThreshold(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double threshold = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_aggressor_threshold(class_instance, threshold, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelMinAggressorSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_min_aggressor_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelMinAggressorSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_min_aggressor_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelMaxError3f(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_max_error_3f(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelMaxError3f(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double max_error_3f = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_max_error_3f(class_instance, max_error_3f, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAdaptiveAmpMax(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_adaptive_amp_max(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAdaptiveAmpMax(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double adaptive_amp_max = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_adaptive_amp_max(class_instance, adaptive_amp_max, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAdaptiveAmpMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_adaptive_amp_min(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAdaptiveAmpMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double adaptive_amp_min = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_adaptive_amp_min(class_instance, adaptive_amp_min, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAratioMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_aratio_min(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAratioMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double aratio_min = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_aratio_min(class_instance, aratio_min, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMixedPixelAggressorPhiOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_mixed_pixel_aggressor_phi_offset(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMixedPixelAggressorPhiOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double aggressor_phi_offset = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_mixed_pixel_aggressor_phi_offset(class_instance, aggressor_phi_offset, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetHdrEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_hdr_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetHdrEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_hdr_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetAverageEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_average_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetAverageEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_average_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetAverageNframes(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_average_nframes(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetAverageNframes(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t nframes = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_average_nframes(class_instance, nframes, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetTemporalEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_temporal_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetTemporalEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_temporal_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetTemporalSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_temporal_sigma(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetTemporalSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double sigma = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_temporal_sigma(class_instance, sigma, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetTemporalNframes(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_temporal_nframes(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetTemporalNframes(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t nframes = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_temporal_nframes(class_instance, nframes, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetGaussianEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_gaussian_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetGaussianEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_gaussian_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetGaussianSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_gaussian_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetGaussianSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_gaussian_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetGaussianSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_gaussian_sigma(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetGaussianSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double sigma = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_gaussian_sigma(class_instance, sigma, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMedianEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_median_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMedianEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_median_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetMedianSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_median_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetMedianSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_median_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBilateralEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_bilateral_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetBilateralEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_bilateral_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBilateralSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_bilateral_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetBilateralSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_bilateral_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBilateralSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_bilateral_sigma(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetBilateralSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double sigma = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_bilateral_sigma(class_instance, sigma, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetLocalMeansEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_local_means_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetLocalMeansEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_local_means_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetLocalMeansSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_local_means_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetLocalMeansSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_local_means_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetLocalMeansSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_local_means_sigma(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetLocalMeansSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double sigma = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_local_means_sigma(class_instance, sigma, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetFlyingEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_flying_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetFlyingEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_flying_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetFlyingShape(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_flying_shape(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofProcessingConfigSetFlyingShape(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be FlyingShape");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto shape = static_cast<tof_flying_shape>(enum_2);

    tof_error_t error{nullptr};

    tof_processing_config_set_flying_shape(class_instance, shape, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetFlyingDistance(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_flying_distance(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetFlyingDistance(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t distance = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_flying_distance(class_instance, distance, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetFlyingEdges(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_flying_edges(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetFlyingEdges(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t edges = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_flying_edges(class_instance, edges, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetAmpThresholdEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_amp_threshold_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetAmpThresholdEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_amp_threshold_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetAmpThresholdMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_amp_threshold_min(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetAmpThresholdMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double min = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_amp_threshold_min(class_instance, min, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetAmpThresholdMax(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_amp_threshold_max(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetAmpThresholdMax(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double max = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_amp_threshold_max(class_instance, max, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetDistThresholdEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_dist_threshold_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetDistThresholdEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_dist_threshold_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetDistThresholdMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_dist_threshold_min(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetDistThresholdMin(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double min = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_dist_threshold_min(class_instance, min, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetDistThresholdMax(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_dist_threshold_max(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetDistThresholdMax(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double max = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_dist_threshold_max(class_instance, max, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetRadialScale(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_radial_scale(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetRadialScale(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float scale = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_radial_scale(class_instance, scale, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetRadialAdd(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_radial_add(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetRadialAdd(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float addition = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_radial_add(class_instance, addition, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetIntensityScale(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_intensity_scale(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetIntensityScale(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float scale = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_intensity_scale(class_instance, scale, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetIntensityAdd(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_intensity_add(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetIntensityAdd(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float addition = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_intensity_add(class_instance, addition, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetCharAdd(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_char_add(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetCharAdd(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double addition = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_char_add(class_instance, addition, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetCharMult(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_char_mult(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetCharMult(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const double multiplication = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_char_mult(class_instance, multiplication, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBinningEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_binning_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetBinningEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_binning_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBinningSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_binning_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetBinningSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_binning_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBinningMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_binning_mode(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofProcessingConfigSetBinningMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be BinningMode");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto mode = static_cast<tof_binning_mode>(enum_2);

    tof_error_t error{nullptr};

    tof_processing_config_set_binning_mode(class_instance, mode, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetBinningSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_binning_sigma(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetBinningSigma(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float sigma = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_binning_sigma(class_instance, sigma, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetXyzDimension(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_xyz_dimension(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofProcessingConfigSetXyzDimension(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be XyzDimension");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto dimension = static_cast<tof_xyz_dimension>(enum_2);

    tof_error_t error{nullptr};

    tof_processing_config_set_xyz_dimension(class_instance, dimension, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetRigidTransformationEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_rigid_transformation_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofProcessingConfigSetRigidTransformationEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_processing_config_set_rigid_transformation_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofProcessingConfigGetRigidTransformationMatrix(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_processing_config_get_rigid_transformation_matrix(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 16}, output, output + 16);
  }

  void tofProcessingConfigSetRigidTransformationMatrix(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    data::TypedArray<float> array_2(inputs[2]);
    auto matrix = &array_2.cbegin()[0];

    tof_error_t error{nullptr};

    tof_processing_config_set_rigid_transformation_matrix(class_instance, matrix, &error);
    if (check_error_(error)) return;
  }

  void tofRoiDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto roi = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_roi_delete(roi);
  }

  void tofRoiSensorRows(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_roi_sensor_rows(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofRoiSensorCols(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_roi_sensor_cols(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofRoiGetRowOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_roi_get_row_offset(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofRoiSetRowOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t row_offset = inputs[2][0];

    tof_error_t error{nullptr};

    tof_roi_set_row_offset(class_instance, row_offset, &error);
    if (check_error_(error)) return;
  }

  void tofRoiGetColOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_roi_get_col_offset(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofRoiSetColOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t col_offset = inputs[2][0];

    tof_error_t error{nullptr};

    tof_roi_set_col_offset(class_instance, col_offset, &error);
    if (check_error_(error)) return;
  }

  void tofRoiGetImgRows(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_roi_get_img_rows(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofRoiSetImgRows(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t img_rows = inputs[2][0];

    tof_error_t error{nullptr};

    tof_roi_set_img_rows(class_instance, img_rows, &error);
    if (check_error_(error)) return;
  }

  void tofRoiGetImgCols(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_roi_get_img_cols(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofRoiSetImgCols(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Roi");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t img_cols = inputs[2][0];

    tof_error_t error{nullptr};

    tof_roi_set_img_cols(class_instance, img_cols, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto camera_config = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_camera_config_delete(camera_config);
  }

  void tofCameraConfigNewFromDisk(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_camera_config_new_from_disk(file_location, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraConfigWrite(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_camera_config_write(class_instance, file_location, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetType(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_type(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofCameraConfigReset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_camera_config_reset(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigFrameSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_frame_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigAddFrame(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_camera_config_add_frame(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigDefaultProcessing(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_default_processing(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraConfigEraseFrame(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    tof_camera_config_erase_frame(class_instance, frame, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetPhaseShifts(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_config_get_phase_shifts(class_instance, frame, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<float> phase_shifts(capacity);
    capacity = tof_camera_config_get_phase_shifts(class_instance, frame, phase_shifts.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, phase_shifts.data(), phase_shifts.data() + capacity);
  }

  void tofCameraConfigSetPhaseShifts(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    data::TypedArray<float> phase_shifts = std::move(inputs[3]);

    tof_error_t error{nullptr};

    tof_camera_config_set_phase_shifts(class_instance, frame, &phase_shifts.cbegin()[0], phase_shifts.getNumberOfElements(), &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_config_get_integration_time(class_instance, frame, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<uint32_t> integration_time(capacity);
    capacity = tof_camera_config_get_integration_time(class_instance, frame, integration_time.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, integration_time.data(), integration_time.data() + capacity);
  }

  void tofCameraConfigSetIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    data::TypedArray<uint32_t> integration_time = std::move(inputs[3]);

    tof_error_t error{nullptr};

    tof_camera_config_set_integration_time(class_instance, frame, &integration_time.cbegin()[0], integration_time.getNumberOfElements(), &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetSensorMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_sensor_mode(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofCameraConfigSetSensorMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() != data::ArrayType::UINT32) {
      error_("Input 4 must be SensorMode");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    uint32_t enum_3 = inputs[3][0];
    auto sensor_mode = static_cast<tof_sensor_mode>(enum_3);

    tof_error_t error{nullptr};

    tof_camera_config_set_sensor_mode(class_instance, frame, sensor_mode, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetModulationFrequency(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_modulation_frequency(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetModulationFrequency(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const float modulation_frequency = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_modulation_frequency(class_instance, frame, modulation_frequency, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetDutyCycle(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_duty_cycle(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetDutyCycle(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const float duty_cycle = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_duty_cycle(class_instance, frame, duty_cycle, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetRoi(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_roi(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraConfigSetRoi(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() != data::ArrayType::UINT64) {
      error_("Input 4 must be Roi");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    auto roi = reinterpret_cast<tof_roi_t>(static_cast<uint64_t>(inputs[3][0]));

    tof_error_t error{nullptr};

    tof_camera_config_set_roi(class_instance, frame, roi, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetBinning(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_binning(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetBinning(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const uint8_t binning = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_binning(class_instance, frame, binning, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetFlip(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_flip(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetFlip(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() != data::ArrayType::LOGICAL) {
      error_("Input 4 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const bool flip = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_flip(class_instance, frame, flip, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetMirror(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_mirror(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetMirror(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() != data::ArrayType::LOGICAL) {
      error_("Input 4 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const bool mirror = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_mirror(class_instance, frame, mirror, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetGain(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_gain(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetGain(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const float gain = inputs[2][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_gain(class_instance, gain, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetSyncMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_sync_mode(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetSyncMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t sync_mode = inputs[2][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_sync_mode(class_instance, sync_mode, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigMaximumIntegrationTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_config_maximum_integration_time(class_instance, frame, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<uint32_t> maximum_integration_time(capacity);
    capacity = tof_camera_config_maximum_integration_time(class_instance, frame, maximum_integration_time.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, maximum_integration_time.data(), maximum_integration_time.data() + capacity);
  }

  void tofCameraConfigGetDac(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_config_get_dac(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<uint16_t> dac(capacity);
    capacity = tof_camera_config_get_dac(class_instance, dac.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, dac.data(), dac.data() + capacity);
  }

  void tofCameraConfigSetDac(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    data::TypedArray<uint16_t> dac = std::move(inputs[2]);

    tof_error_t error{nullptr};

    tof_camera_config_set_dac(class_instance, &dac.cbegin()[0], dac.getNumberOfElements(), &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetMlxMipiSpeed(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_mlx_mipi_speed(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetMlxMipiSpeed(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const int32_t mipi_speed = inputs[2][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_mlx_mipi_speed(class_instance, mipi_speed, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetMlxPreheat(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_mlx_preheat(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetMlxPreheat(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const uint32_t preheat = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_mlx_preheat(class_instance, frame, preheat, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetMlxPreheatEnable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_mlx_preheat_enable(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetMlxPreheatEnable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() != data::ArrayType::LOGICAL) {
      error_("Input 4 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const bool enable = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_mlx_preheat_enable(class_instance, frame, enable, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigSetOptKeaNiosHex(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_camera_config_set_opt_kea_nios_hex(class_instance, file_location, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetOptKeaSubQuad(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_opt_kea_sub_quad(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 2}, output, output + 2);
  }

  void tofCameraConfigSetOptKeaSubQuad(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    data::TypedArray<int32_t> array_2(inputs[2]);
    auto subs_quads = &array_2.cbegin()[0];

    tof_error_t error{nullptr};

    tof_camera_config_set_opt_kea_sub_quad(class_instance, subs_quads, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetProcessing(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_processing(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraConfigSetProcessing(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    auto processing = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_camera_config_set_processing(class_instance, processing, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetFrameTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_frame_time(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetFrameTime(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const uint32_t frame_time = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_frame_time(class_instance, frame, frame_time, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetGlobalPhaseOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_global_phase_offset(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 2}, output, output + 2);
  }

  void tofCameraConfigSetGlobalPhaseOffset(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    data::TypedArray<float> array_3(inputs[3]);
    auto phase_offset = &array_3.cbegin()[0];

    tof_error_t error{nullptr};

    tof_camera_config_set_global_phase_offset(class_instance, frame, phase_offset, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetIlluminationMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_illumination_mode(class_instance, frame, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigSetIlluminationMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    const uint8_t illumination_mode = inputs[3][0];

    tof_error_t error{nullptr};

    tof_camera_config_set_illumination_mode(class_instance, frame, illumination_mode, &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetImageOffsets(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_config_get_image_offsets(class_instance, frame, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<float> image_offsets(capacity);
    capacity = tof_camera_config_get_image_offsets(class_instance, frame, image_offsets.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, image_offsets.data(), image_offsets.data() + capacity);
  }

  void tofCameraConfigSetImageOffsets(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame = inputs[2][0];

    data::TypedArray<float> image_offsets = std::move(inputs[3]);

    tof_error_t error{nullptr};

    tof_camera_config_set_image_offsets(class_instance, frame, &image_offsets.cbegin()[0], image_offsets.getNumberOfElements(), &error);
    if (check_error_(error)) return;
  }

  void tofCameraConfigGetRgbWidth(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_rgb_width(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigGetRgbHeight(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_rgb_height(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraConfigGetTriggerMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_config_get_trigger_mode(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(static_cast<uint32_t>(output));;
  }

  void tofCameraConfigSetTriggerMode(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CameraConfig");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be TriggerMode");
    }

    auto class_instance = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto trigger_mode = static_cast<tof_trigger_mode>(enum_2);

    tof_error_t error{nullptr};

    tof_camera_config_set_trigger_mode(class_instance, trigger_mode, &error);
    if (check_error_(error)) return;
  }

  void tofCalibrationDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto calibration = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_calibration_delete(calibration);
  }

  void tofCalibrationNewFromDisk(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_calibration_new_from_disk(file_location, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCalibrationWrite(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_calibration_write(class_instance, file_location, &error);
    if (check_error_(error)) return;
  }

  void tofCalibrationGetCalibratedFrequencies(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_calibration_get_calibrated_frequencies(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<float> calibrated_frequencies(capacity);
    capacity = tof_calibration_get_calibrated_frequencies(class_instance, calibrated_frequencies.data(), capacity, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, capacity}, calibrated_frequencies.data(), calibrated_frequencies.data() + capacity);
  }

  void tofCalibrationGetFocalLengthX(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_focal_length_x(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCalibrationGetFocalLengthY(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_focal_length_y(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCalibrationGetPrincipalPointX(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_principal_point_x(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCalibrationGetPrincipalPointY(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_principal_point_y(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCalibrationGetDepthCameraMatrix(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_depth_camera_matrix(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 9}, output, output + 9);
  }

  void tofCalibrationGetDepthDistortionCoefficients(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_depth_distortion_coefficients(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 5}, output, output + 5);
  }

  void tofCalibrationGetRgbCameraMatrix(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_rgb_camera_matrix(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 9}, output, output + 9);
  }

  void tofCalibrationGetRgbDistortionCoefficients(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_rgb_distortion_coefficients(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 5}, output, output + 5);
  }

  void tofCalibrationGetRotationVector(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_rotation_vector(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 3}, output, output + 3);
  }

  void tofCalibrationGetTranslationVector(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Calibration");
    }

    auto class_instance = reinterpret_cast<tof_calibration_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_calibration_get_translation_vector(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createArray({1, 3}, output, output + 3);
  }

  void tofCameraDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto camera = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_camera_delete(camera);
  }

  void tofCameraStart(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofCameraStart(outputs, inputs, factory_);
  }

  void tofCameraStop(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_camera_stop(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofCameraIsStreaming(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_is_streaming(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraIsConnected(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_is_connected(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraGetStreamList(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_get_stream_list(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_stream_t> streams(capacity);
    capacity = tof_camera_get_stream_list(class_instance, streams.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : streams) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofCameraSetStreamList(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be Stream");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    data::TypedArray<uint64_t> tempArray2 = std::move(inputs[2]);
    std::vector<tof_stream_t> streams;
    streams.reserve(tempArray2.getNumberOfElements());
    std::transform(tempArray2.begin(), tempArray2.end(), std::back_inserter(streams), [](uint64_t val) { return reinterpret_cast<tof_stream_t>(val); });

    tof_error_t error{nullptr};

    tof_camera_set_stream_list(class_instance, streams.data(), streams.size(), &error);
    if (check_error_(error)) return;
  }

  void tofCameraIsStreamListSet(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_is_stream_list_set(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraGetSetStreamList(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_camera_get_set_stream_list(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_stream_t> streams(capacity);
    capacity = tof_camera_get_set_stream_list(class_instance, streams.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : streams) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofCameraGetProcessConfig(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_get_process_config(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraSetProcessConfig(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    auto config = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_camera_set_process_config(class_instance, config, &error);
    if (check_error_(error)) return;
  }

  void tofCameraHasFrames(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_has_frames(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraGetFrames(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofCameraGetFrames(outputs, inputs, factory_);
  }

  void tofCameraClearBuffer(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_camera_clear_buffer(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofCameraGetBufferSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_get_buffer_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraSetBufferSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_camera_set_buffer_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofCameraGetCameraConfig(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_get_camera_config(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraGetSerial(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_get_serial(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraGetCalibration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_get_calibration(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCameraGetUserPointerCapacity(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_camera_get_user_pointer_capacity(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCameraSetUserPointerCapacity(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t capacity = inputs[2][0];

    tof_error_t error{nullptr};

    tof_camera_set_user_pointer_capacity(class_instance, capacity, &error);
    if (check_error_(error)) return;
  }

  void tofCameraClearUserPointers(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    auto class_instance = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_camera_clear_user_pointers(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofSelectStreams(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be FrameType");
    }

    auto camera = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    data::TypedArray<uint32_t> tempArray2 = std::move(inputs[2]);
    std::vector<tof_frame_type> frame_types;
    frame_types.reserve(tempArray2.getNumberOfElements());
    std::transform(tempArray2.begin(), tempArray2.end(), std::back_inserter(frame_types), [](uint32_t val) { return static_cast<tof_frame_type>(val); });

    tof_error_t error{nullptr};

    const auto output = tof_select_streams(camera, frame_types.data(), frame_types.size(), &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofSelectStreamsModFreq(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 1) {
      error_("4 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be Camera");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be FrameType");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto camera = reinterpret_cast<tof_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    data::TypedArray<uint32_t> tempArray2 = std::move(inputs[2]);
    std::vector<tof_frame_type> frame_types;
    frame_types.reserve(tempArray2.getNumberOfElements());
    std::transform(tempArray2.begin(), tempArray2.end(), std::back_inserter(frame_types), [](uint32_t val) { return static_cast<tof_frame_type>(val); });

    const float mod_freq = inputs[3][0];

    tof_error_t error{nullptr};

    const auto output = tof_select_streams_mod_freq(camera, frame_types.data(), frame_types.size(), mod_freq, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto kea_camera = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_kea_camera_delete(kea_camera);
  }

  void tofKeaCameraNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto processing_config = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string serial_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      serial_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      serial_str = string_array[0];
    }
    const char* serial = serial_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_new(processing_config, serial, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofKeaCameraOnCameraProcessingCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_on_camera_processing_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraGetOnCameraProcessing(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_get_on_camera_processing(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraSetOnCameraProcessing(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool on_camera_processing = inputs[2][0];

    tof_error_t error{nullptr};

    tof_kea_camera_set_on_camera_processing(class_instance, on_camera_processing, &error);
    if (check_error_(error)) return;
  }

  void tofKeaCameraGetDelay(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_get_delay(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraSetDelay(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint32_t delay = inputs[2][0];

    tof_error_t error{nullptr};

    tof_kea_camera_set_delay(class_instance, delay, &error);
    if (check_error_(error)) return;
  }

  void tofKeaCameraGetPacketSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_get_packet_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraSetPacketSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint16_t size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_kea_camera_set_packet_size(class_instance, size, &error);
    if (check_error_(error)) return;
  }

  void tofKeaCameraSetCameraConfig(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    auto camera_config = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_kea_camera_set_camera_config(class_instance, camera_config, &error);
    if (check_error_(error)) return;
  }

  void tofKeaCameraSetConfigurations(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be CameraConfig");
    }

    if (inputs[3].getType() != data::ArrayType::UINT64) {
      error_("Input 4 must be ProcessingConfig");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    auto camera_config = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[2][0]));

    auto processing_config = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[3][0]));

    tof_error_t error{nullptr};

    tof_kea_camera_set_configurations(class_instance, camera_config, processing_config, &error);
    if (check_error_(error)) return;
  }

  void tofKeaCameraVersion(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_version(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraSoftwareTriggerCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_software_trigger_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraSoftwareTrigger(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_kea_camera_software_trigger(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofKeaCameraRemoteUpdateCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_kea_camera_remote_update_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofKeaCameraRemoteUpdate(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be KeaCamera");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_kea_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_kea_camera_remote_update(class_instance, file_location, &error);
    if (check_error_(error)) return;
  }

  void tofDiscoveredKeaDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be DiscoveredKea");
    }

    auto discovered_kea = reinterpret_cast<tof_discovered_kea_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_discovered_kea_delete(discovered_kea);
  }

  void tofDiscoveredKeaSerial(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be DiscoveredKea");
    }

    auto class_instance = reinterpret_cast<tof_discovered_kea_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_discovered_kea_serial(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDiscoveredKeaInfo(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be DiscoveredKea");
    }

    auto class_instance = reinterpret_cast<tof_discovered_kea_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_discovered_kea_info(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDiscoverKeaCameras(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 1) {
      error_("1 inputs are required and 1 outputs are returned");
    }

    tof_error_t error{nullptr};

    size_t capacity = tof_discover_kea_cameras(nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_discovered_kea_t> available_kea_cameras(capacity);
    capacity = tof_discover_kea_cameras(available_kea_cameras.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : available_kea_cameras) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofCreateKeaCameraGige(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 1) {
      error_("4 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto processing_config = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string serial_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      serial_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      serial_str = string_array[0];
    }
    const char* serial = serial_str.c_str();
    const uint16_t packet_size = inputs[3][0];

    tof_error_t error{nullptr};

    const auto output = tof_create_kea_camera_gige(processing_config, serial, packet_size, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCrashReportDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CrashReport");
    }

    auto crash_report = reinterpret_cast<tof_crash_report_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_crash_report_delete(crash_report);
  }

  void tofCrashReportNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    std::string serial_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      serial_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      serial_str = string_array[0];
    }
    const char* serial = serial_str.c_str();
    std::string description_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      description_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      description_str = string_array[0];
    }
    const char* description = description_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_crash_report_new(serial, description, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCrashReportGetDescription(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CrashReport");
    }

    auto class_instance = reinterpret_cast<tof_crash_report_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_crash_report_get_description(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCrashReportSetDescription(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CrashReport");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_crash_report_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string description_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      description_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      description_str = string_array[0];
    }
    const char* description = description_str.c_str();
    tof_error_t error{nullptr};

    tof_crash_report_set_description(class_instance, description, &error);
    if (check_error_(error)) return;
  }

  void tofCrashReportGetReport(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CrashReport");
    }

    auto class_instance = reinterpret_cast<tof_crash_report_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_crash_report_get_report(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCrashReportSave(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CrashReport");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_crash_report_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_name_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_name_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_name_str = string_array[0];
    }
    const char* file_name = file_name_str.c_str();
    tof_error_t error{nullptr};

    tof_crash_report_save(class_instance, file_name, &error);
    if (check_error_(error)) return;
  }

  void tofGetVersion(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 1) {
      error_("1 inputs are required and 1 outputs are returned");
    }

    tof_error_t error{nullptr};

    const auto output = tof_get_version(&error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofLogToConsole(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 0) {
      error_("1 inputs are required and 0 outputs are returned");
    }

    tof_error_t error{nullptr};

    tof_log_to_console(&error);
    if (check_error_(error)) return;
  }

  void tofLogToFile(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    std::string file_location_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    tof_log_to_file(file_location, &error);
    if (check_error_(error)) return;
  }

  void tofLogDrop(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 0) {
      error_("1 inputs are required and 0 outputs are returned");
    }

    tof_error_t error{nullptr};

    tof_log_drop(&error);
    if (check_error_(error)) return;
  }

  void tofCsfCameraDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfCamera");
    }

    auto csf_camera = reinterpret_cast<tof_csf_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_csf_camera_delete(csf_camera);
  }

  void tofCsfCameraNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be ProcessingConfig");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto processing_config = reinterpret_cast<tof_processing_config_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string file_location_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      file_location_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      file_location_str = string_array[0];
    }
    const char* file_location = file_location_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_csf_camera_new(processing_config, file_location, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofCsfCameraGetFramesAt(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfCamera");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_csf_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t frame_nr = inputs[2][0];

    tof_error_t error{nullptr};

    size_t capacity = tof_csf_camera_get_frames_at(class_instance, frame_nr, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_data_t> frames(capacity);
    capacity = tof_csf_camera_get_frames_at(class_instance, frame_nr, frames.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : frames) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofCsfCameraGetCurrentFrame(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfCamera");
    }

    auto class_instance = reinterpret_cast<tof_csf_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_camera_get_current_frame(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfCameraGetFrameNumber(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfCamera");
    }

    auto class_instance = reinterpret_cast<tof_csf_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_camera_get_frame_number(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfCameraGetFps(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfCamera");
    }

    auto class_instance = reinterpret_cast<tof_csf_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_csf_camera_get_fps(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofCsfCameraSetFps(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be CsfCamera");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_csf_camera_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t fps = inputs[2][0];

    tof_error_t error{nullptr};

    tof_csf_camera_set_fps(class_instance, fps, &error);
    if (check_error_(error)) return;
  }

  void tofDiscoveryMessageDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be DiscoveryMessage");
    }

    auto discovery_message = reinterpret_cast<tof_discovery_message_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_discovery_message_delete(discovery_message);
  }

  void tofDiscoveryMessageIp(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be DiscoveryMessage");
    }

    auto class_instance = reinterpret_cast<tof_discovery_message_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_discovery_message_ip(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofDiscoveryMessageSerial(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be DiscoveryMessage");
    }

    auto class_instance = reinterpret_cast<tof_discovery_message_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_discovery_message_serial(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofPersistentIpDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    auto persistent_ip = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_persistent_ip_delete(persistent_ip);
  }

  void tofPersistentIpNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 5 || outputs.size() != 1) {
      error_("5 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    if (inputs[3].getType() != data::ArrayType::CHAR &&
        inputs[3].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 4 must be a string");
    }

    if (inputs[4].getType() != data::ArrayType::LOGICAL) {
      error_("Input 5 must be either true or false");
    }

    std::string ip_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      ip_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      ip_str = string_array[0];
    }
    const char* ip = ip_str.c_str();
    std::string netmask_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      netmask_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      netmask_str = string_array[0];
    }
    const char* netmask = netmask_str.c_str();
    std::string gateway_str;
    if (inputs[3].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[3]);
      gateway_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[3]);
      gateway_str = string_array[0];
    }
    const char* gateway = gateway_str.c_str();
    const bool enabled = inputs[4][0];

    tof_error_t error{nullptr};

    const auto output = tof_persistent_ip_new(ip, netmask, gateway, enabled, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofPersistentIpGetIp(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_persistent_ip_get_ip(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofPersistentIpSetIp(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string ip_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      ip_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      ip_str = string_array[0];
    }
    const char* ip = ip_str.c_str();
    tof_error_t error{nullptr};

    tof_persistent_ip_set_ip(class_instance, ip, &error);
    if (check_error_(error)) return;
  }

  void tofPersistentIpGetNetmask(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_persistent_ip_get_netmask(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofPersistentIpSetNetmask(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string netmask_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      netmask_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      netmask_str = string_array[0];
    }
    const char* netmask = netmask_str.c_str();
    tof_error_t error{nullptr};

    tof_persistent_ip_set_netmask(class_instance, netmask, &error);
    if (check_error_(error)) return;
  }

  void tofPersistentIpGetGateway(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_persistent_ip_get_gateway(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofPersistentIpSetGateway(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string gateway_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      gateway_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      gateway_str = string_array[0];
    }
    const char* gateway = gateway_str.c_str();
    tof_error_t error{nullptr};

    tof_persistent_ip_set_gateway(class_instance, gateway, &error);
    if (check_error_(error)) return;
  }

  void tofPersistentIpGetEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_persistent_ip_get_enabled(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofPersistentIpSetEnabled(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be PersistentIp");
    }

    if (inputs[2].getType() != data::ArrayType::LOGICAL) {
      error_("Input 3 must be either true or false");
    }

    auto class_instance = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[1][0]));

    const bool enabled = inputs[2][0];

    tof_error_t error{nullptr};

    tof_persistent_ip_set_enabled(class_instance, enabled, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto gige_interface = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_gige_interface_delete(gige_interface);
  }

  void tofGigeInterfaceNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() < data::ArrayType::DOUBLE ||
        inputs[1].getType() > data::ArrayType::UINT64) {
      error_("Input 2 must be numerical");
    }

    const uint16_t port = inputs[1][0];

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_new(port, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofGigeInterfaceDiscover(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    size_t capacity = tof_gige_interface_discover(class_instance, nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_discovery_message_t> messages(capacity);
    capacity = tof_gige_interface_discover(class_instance, messages.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : messages) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofGigeInterfaceDiscoverOne(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_discover_one(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofGigeInterfaceFind(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() != data::ArrayType::CHAR &&
        inputs[2].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 3 must be a string");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    std::string serial_str;
    if (inputs[2].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[2]);
      serial_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[2]);
      serial_str = string_array[0];
    }
    const char* serial = serial_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_find(class_instance, serial, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofGigeInterfaceConnect(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be DiscoveryMessage");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    auto message = reinterpret_cast<tof_discovery_message_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_gige_interface_connect(class_instance, message, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceDisconnect(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_gige_interface_disconnect(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceIsConnected(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_is_connected(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceGetStreamPacketSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_get_stream_packet_size(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceSetStreamPacketSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint16_t packet_size = inputs[2][0];

    tof_error_t error{nullptr};

    tof_gige_interface_set_stream_packet_size(class_instance, packet_size, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceTestStreamPacketSize(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint16_t port = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_test_stream_packet_size(class_instance, port, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceGetDelay(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_get_delay(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceSetDelay(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint32_t delay = inputs[2][0];

    tof_error_t error{nullptr};

    tof_gige_interface_set_delay(class_instance, delay, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceDownloadConfiguration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint16_t port = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_download_configuration(class_instance, port, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofGigeInterfaceDownloadCalibration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint16_t port = inputs[2][0];

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_download_calibration(class_instance, port, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofGigeInterfaceUploadConfiguration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 4 || outputs.size() != 0) {
      error_("4 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be CameraConfig");
    }

    if (inputs[3].getType() < data::ArrayType::DOUBLE ||
        inputs[3].getType() > data::ArrayType::UINT64) {
      error_("Input 4 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    auto config = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[2][0]));

    const uint16_t port = inputs[3][0];

    tof_error_t error{nullptr};

    tof_gige_interface_upload_configuration(class_instance, config, port, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceDepthStreamCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be DepthStreamType");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto stream = static_cast<tof_depth_stream_type>(enum_2);

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_depth_stream_capable(class_instance, stream, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceStartDepthStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofGigeInterfaceStartDepthStream(outputs, inputs, factory_);
  }

  void tofGigeInterfaceStopDepthStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_gige_interface_stop_depth_stream(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceHasDepthData(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_has_depth_data(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceGetDepthData(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofGigeInterfaceGetDepthData(outputs, inputs, factory_);
  }

  void tofGigeInterfaceImageStreamCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_image_stream_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceStartImageStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const uint16_t port = inputs[2][0];

    tof_error_t error{nullptr};

    tof_gige_interface_start_image_stream(class_instance, port, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceStopImageStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_gige_interface_stop_image_stream(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceHasImageData(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_has_image_data(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceGetImageData(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofGigeInterfaceGetImageData(outputs, inputs, factory_);
  }

  void tofGigeInterfacePersistentIpCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_persistent_ip_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceGetPersistentIp(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_get_persistent_ip(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofGigeInterfaceSetPersistentIp(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be PersistentIp");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    auto persistent_ip = reinterpret_cast<tof_persistent_ip_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_gige_interface_set_persistent_ip(class_instance, persistent_ip, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceGetUserPointerCapacity(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_get_user_pointer_capacity(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceSetUserPointerCapacity(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t capacity = inputs[2][0];

    tof_error_t error{nullptr};

    tof_gige_interface_set_user_pointer_capacity(class_instance, capacity, &error);
    if (check_error_(error)) return;
  }

  void tofGigeInterfaceVersion(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_version(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceSoftwareTriggerCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_gige_interface_software_trigger_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofGigeInterfaceSoftwareTrigger(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be GigeInterface");
    }

    auto class_instance = reinterpret_cast<tof_gige_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_gige_interface_software_trigger(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofUsbDeviceDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbDevice");
    }

    auto usb_device = reinterpret_cast<tof_usb_device_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_usb_device_delete(usb_device);
  }

  void tofUsbDeviceSerial(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbDevice");
    }

    auto class_instance = reinterpret_cast<tof_usb_device_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_device_serial(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceDelete(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto usb_interface = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_usb_interface_delete(usb_interface);
  }

  void tofUsbInterfaceNew(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbDevice");
    }

    auto usb_device = reinterpret_cast<tof_usb_device_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_new(usb_device, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUsbInterfaceIsConnected(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_is_connected(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceTestStreamSpeed(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_test_stream_speed(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceDownloadConfiguration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_download_configuration(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUsbInterfaceDownloadCalibration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_download_calibration(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUsbInterfaceUploadConfiguration(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    if (inputs[2].getType() != data::ArrayType::UINT64) {
      error_("Input 3 must be CameraConfig");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    auto config = reinterpret_cast<tof_camera_config_t>(static_cast<uint64_t>(inputs[2][0]));

    tof_error_t error{nullptr};

    tof_usb_interface_upload_configuration(class_instance, config, &error);
    if (check_error_(error)) return;
  }

  void tofUsbInterfaceDepthStreamCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 1) {
      error_("3 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    if (inputs[2].getType() != data::ArrayType::UINT32) {
      error_("Input 3 must be DepthStreamType");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    uint32_t enum_2 = inputs[2][0];
    auto stream = static_cast<tof_depth_stream_type>(enum_2);

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_depth_stream_capable(class_instance, stream, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceStartDepthStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofUsbInterfaceStartDepthStream(outputs, inputs, factory_);
  }

  void tofUsbInterfaceStopDepthStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_usb_interface_stop_depth_stream(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofUsbInterfaceHasDepthData(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_has_depth_data(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceGetDepthData(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofUsbInterfaceGetDepthData(outputs, inputs, factory_);
  }

  void tofUsbInterfaceImageStreamCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_image_stream_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceStartImageStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_usb_interface_start_image_stream(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofUsbInterfaceStopImageStream(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_usb_interface_stop_image_stream(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofUsbInterfaceHasImageData(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_has_image_data(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceGetImageData(mex::ArgumentList outputs, mex::ArgumentList inputs) {
impl::tofUsbInterfaceGetImageData(outputs, inputs, factory_);
  }

  void tofUsbInterfaceGetUserPointerCapacity(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_get_user_pointer_capacity(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceSetUserPointerCapacity(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 3 || outputs.size() != 0) {
      error_("3 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    if (inputs[2].getType() < data::ArrayType::DOUBLE ||
        inputs[2].getType() > data::ArrayType::UINT64) {
      error_("Input 3 must be numerical");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    const size_t capacity = inputs[2][0];

    tof_error_t error{nullptr};

    tof_usb_interface_set_user_pointer_capacity(class_instance, capacity, &error);
    if (check_error_(error)) return;
  }

  void tofUsbInterfaceVersion(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_version(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceSoftwareTriggerCapable(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    const auto output = tof_usb_interface_software_trigger_capable(class_instance, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(output);;
  }

  void tofUsbInterfaceSoftwareTrigger(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 0) {
      error_("2 inputs are required and 0 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::UINT64) {
      error_("Input 2 must be UsbInterface");
    }

    auto class_instance = reinterpret_cast<tof_usb_interface_t>(static_cast<uint64_t>(inputs[1][0]));

    tof_error_t error{nullptr};

    tof_usb_interface_software_trigger(class_instance, &error);
    if (check_error_(error)) return;
  }

  void tofUsbDeviceDiscover(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 1) {
      error_("1 inputs are required and 1 outputs are returned");
    }

    tof_error_t error{nullptr};

    size_t capacity = tof_usb_device_discover(nullptr, 0, &error);
    if (check_error_(error)) return;
    std::vector<tof_usb_device_t> usb_devices(capacity);
    capacity = tof_usb_device_discover(usb_devices.data(), capacity, &error);
    if (check_error_(error)) return;
    std::vector<uint64_t> output;
    output.reserve(capacity);
    for (auto item : usb_devices) {
      output.push_back(reinterpret_cast<uint64_t>(item));
    }

    outputs[0] = factory_.createArray({1, capacity}, output.data(), output.data() + capacity);
  }

  void tofUsbDeviceDiscoverOne(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 1 || outputs.size() != 1) {
      error_("1 inputs are required and 1 outputs are returned");
    }

    tof_error_t error{nullptr};

    const auto output = tof_usb_device_discover_one(&error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

  void tofUsbDeviceFind(mex::ArgumentList outputs, mex::ArgumentList inputs) {

    if (inputs.size() != 2 || outputs.size() != 1) {
      error_("2 inputs are required and 1 outputs are returned");
    }

    if (inputs[1].getType() != data::ArrayType::CHAR &&
        inputs[1].getType() != data::ArrayType::MATLAB_STRING) {
      error_("Input 2 must be a string");
    }

    std::string serial_str;
    if (inputs[1].getType() == data::ArrayType::CHAR) {
      data::CharArray char_array(inputs[1]);
      serial_str = char_array.toAscii();
    } else {
      data::StringArray string_array(inputs[1]);
      serial_str = string_array[0];
    }
    const char* serial = serial_str.c_str();
    tof_error_t error{nullptr};

    const auto output = tof_usb_device_find(serial, &error);
    if (check_error_(error)) return;
    outputs[0] = factory_.createScalar(reinterpret_cast<uint64_t>(output));;
  }

};
